from mitoinstaller.installer_steps import (ALL_INSTALLER_STEPS,
                                           run_installer_steps)
from mitoinstaller.installer_steps.initial_installer_steps import initial_install_step_create_user
from mitoinstaller.log_utils import log_error


def do_install() -> None:
    """
    Runs the installer steps to install the `mitosheet` package.

    Notably, the process for installing Mito initially and upgrading Mito are
    identical. As such, we reuse this function to upgrade, just with different
    error and logging messages.
    """
    # We need to create the user json file before we can run anything,
    # as this creates the experiment variant we use throughout the rest of the
    # installer.
    try:
        initial_install_step_create_user()
    except:
        log_error('install_failed', {'installer_step_name': 'create_user'})
        log_error('create_user_failed')
        exit(1)

    # Run the installer steps
    run_installer_steps(ALL_INSTALLER_STEPS)



from distutils.core import setup
from mitoinstaller import __version__
from setuptools import find_packages


setup(
    name                = 'mitoinstaller',
    version             = __version__,
    packages            = find_packages(where='.', exclude='tests'),
    install_requires    = ['analytics-python', 'colorama', 'termcolor'],
    author              = 'Mito',
    author_email        = 'naterush1997@gmail.com',
    license             = 'AGPL-3.0-only',
    url                 = 'https://github.com/mito-ds/monorepo',
    long_description    = 'The mitoinstaller package allows you to install the mitosheet package in your local JupyterLab instance. It logs anonymous data about installation, including if it is successful or why it failed.',
)
